/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
**/

#ifndef NFSDEFAULTAPPLICATIONS_H
#define NFSDEFAULTAPPLICATIONS_H

#ifdef __cplusplus
extern "C"
{
#endif

    /**
     * 按指定“mimetype”获取默认打开工具
     * @param[in] mime_type 存放mime类型
     * @param[out] result 存放默认应用名称
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_app_by_mimetype(const unsigned char *mimetype, unsigned char **default_app);

    /**
     * 获取系统默认浏览器
     * @param[out] browser 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_browser(unsigned char **browser);

    /**
     * 获取系统默认文本编辑器
     * @param[out] text_editor 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_text_editor(unsigned char **text_editor);

    /**
     * 获取系统默认图片查看器
     * @param[out] image_viewer 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_image_viewer(unsigned char **image_viewer);

    /**
     * 获取系统默认word文档查看器
     * @param[out] word_viewer 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_word_viewer(unsigned char **word_viewer);

    /**
     * 获取系统默认pdf文档查看器
     * @param[out] pdf_viewer 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_pdf_viewer(unsigned char **pdf_viewer);

    /**
     * 获取系统默认音乐播放器
     * @param[out] music_player 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_music_player(unsigned char **music_player);

    /**
     * 获取系统默认视频播放器
     * @param[out] video_player 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_video_player(unsigned char **video_player);

    /**
     * 获取系统邮件客户端
     * @param[out] mail 存放默认应用名称，设置时可作为传入参数
     * @return 成功返回0，否则返回错误码
     * @note 结果使用完后需释放
     * @see 无
     */
    int fdk_defaultapp_get_mail(unsigned char **mail);

#ifdef __cplusplus
}
#endif

#endif // NFSDEFAULTAPPLICATIONS_H
