/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
**/

#ifndef LIBFDPKGINFO_H
#define LIBFDPKGINFO_H

#include <stdio.h>
#ifdef __cplusplus
extern "C" {
#endif

/**
 * 获取系统中所有包列表
 * @param[out] 存放包列表信息的个数
 * @return 包含包列表名称的指针数组，由API内部分配。最后一个元素为NULL。
 * @warning 调用完后使用fdk_pkginfo_free_all_pkgs_list释放内存
 * @note 无
 * @see 无
 */
char **fdk_pkginfo_get_all_pkgs_list(int *count);

/**
 * 用于释放由fdk_pkginfo_get_all_pkgs_list分配的内存
 * @param[in] pkg_list 存放包列表信息的指针
 * @return 无
 * @warning 无
 * @note 无
 * @see 无
 */
void fdk_pkginfo_free_all_pkgs_list(char **pkg_list);

/**
 * 获取系统中所有异常状态的包列表
 * @param[out] 存放包列表信息的个数
 * @return 包含包列表名称的指针数组，由API内部分配。最后一个元素为NULL。
 * @warning 确保调用完后释放error_pkg_list所指向的内存
 * @note 无
 * @see 无
 */
#if 0
char **fdk_pkginfo_get_error_pkgs_list(int *count);

/**
 * 获取系统中指定已安装包的版本号
 * @param[out] version 用于存放版本信息的缓冲区。
 * @param[in] pkg_name 包名。
 * @param[in] size 版本字符串缓冲区的大小
 * @return 成功返回0，失败返回错误码
 * @warning 无
 * @note 无
 * @see 无
 */
#endif
int fdk_pkginfo_get_installed_pkg_version(const char *pkg_name, char *version, size_t size);

/**
 * 检测指定包名的软件包是否已正确安装
 * @param[out] isInstalled 0代表未正确安装，1代表正确安装。
 * @param[in] pkg_name 包名。
 * @return 成功返回0，失败返回错误码
 * @warning 无
 * @note 无
 * @see 无
 */
int fdk_pkginfo_is_pkg_installed(const  char *pkg_name, int *isInstalled);

/**
 * 获取指定软件包的描述
 * @param[out] description 用于存放描述信息的缓冲区。
 * @param[in] pkg_name 包名。
 * @param[in] size 描述信息缓冲区的大小。
 * @return 成功返回0，失败返回错误码
 * @warning 确保传入的pkg_name有效、确保调用完后释放description所指向的内存
 * @note 无
 * @see 无
 */
int fdk_pkginfo_get_pkg_description(const  char *pkg_name,  char *description, size_t size);

/**
 * 获取指定软件的所有文件列表
 * @param[in] pkg_name 包名。
 * @param[in] count 指定软件的所有文件列表的个数
 * @return 包含文件列表名称的指针数组
 * @warning 确保传入的pkg_name有效，确保调用完后free_file_list释放内存
 * @note 无
 * @see 无
 */
char ** fdk_pkginfo_get_pkg_files(const char *pkg_name, int *count);

/**
 * 用于释放由fdk_pkginfo_get_pkg_files分配的内存
 * @param[in] pkg_list 存放文件列表信息的指针
 * @param[in] count 文件列表个数
 * @return 无
 * @warning 无
 * @note 无
 * @see 无
 */
void free_file_list(char **file_list, int count);

/**
 * 判断指定软件包是否可以被移除
 * @param[in] pkg_name 包名
 * @param[out] isEnable 是否可以被移除
 * @return 成功返回0，失败返回错误码
 * @warning 确保pkg_name有效
 * @note 无
 * @see 无
 */
int fdk_pkginfo_pkg_remove_enabled(const  char *pkg_name,int *isEnable);


#ifdef __cplusplus
}
#endif


#endif // FDPKGINFO_H
